==> sptk-2.3.28.tbz2: sptk-2.3.28/src/CFontComboBox.cpp <==
/***************************************************************************
                          SIMPLY POWERFUL TOOLKIT (SPTK)
                          CFontComboBox.cpp  -  description
                             -------------------
    begin                : 11 June 2003
    copyright            : (C) 2000-2003 by Alexey S.Parshin
    email                : alexeyp@gmail.com
 ***************************************************************************/

/***************************************************************************
   This library is free software; you can redistribute it and/or modify it 
   under the terms of the GNU Library General Public License as published by
   the Free Software Foundation; either version 2 of the License, or (at 
   your option) any later version.

   This library is distributed in the hope that it will be useful, but 
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Library
   General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; if not, write to the Free Software Foundation, 
   Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.

   Please report all bugs and problems to "alexeyp@gmail.com"
 ***************************************************************************/

#include <FL/Fl.H>

#include <sptk/CColumn.h>
#include <sptk/CDBListView.h>
#include <sptk/CFontComboBox.h>

void CFontComboBox::loadFonts() {
   CStringList fontNames;
   int k = Fl::set_fonts("*");
   for (int i = 0; i < k; i++) {
      int t; 
      fontNames.add(Fl::get_font_name((Fl_Font)i,&t),i);
   }
   addRows("Fonts",fontNames);
   columns()[unsigned(0)].width(150);
   sortColumn(0);
   m_list->autoRowHeight(true);
}

CFontComboBox::CFontComboBox(const char * label,int layoutSize,CLayoutAlign layoutAlignment)
: CComboBox(label,layoutSize,layoutAlignment) {
   loadFonts();
}

#ifdef __COMPATIBILITY_MODE__ 
CFontComboBox::CFontComboBox(int x,int y,int w,int h,const char *l)
: CComboBox(x,y,w,h,l) {
   loadFonts();
}
#endif

==> sptk-3.0.6.tbz2: sptk-3.0.6/src/CFontComboBox.cpp <==
/***************************************************************************
                          SIMPLY POWERFUL TOOLKIT (SPTK)
                          CFontComboBox.cpp  -  description
                             -------------------
    begin                : 11 June 2003
    copyright            : (C) 2000-2005 by Alexey S.Parshin
    email                : alexeyp@gmail.com
 ***************************************************************************/

/***************************************************************************
   This library is free software; you can redistribute it and/or modify it 
   under the terms of the GNU Library General Public License as published by
   the Free Software Foundation; either version 2 of the License, or (at 
   your option) any later version.

   This library is distributed in the hope that it will be useful, but 
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Library
   General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; if not, write to the Free Software Foundation, 
   Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.

   Please report all bugs and problems to "alexeyp@gmail.com"
 ***************************************************************************/

#include <FL/Fl.H>

#include <sptk3/CColumn.h>
#include <sptk3/CDBListView.h>
#include <sptk3/CFontComboBox.h>

void CFontComboBox::loadFonts() {
   CStrings fontNames;
   int k = Fl::set_fonts("*");
   for (int i = 0; i < k; i++) {
      int t; 
	  idstring fontIdString(Fl::get_font_name((Fl_Font)i,&t),i);
      fontNames.push_back(fontIdString);
   }
   addRows("Fonts",fontNames);
   columns()[unsigned(0)].width(150);
   sortColumn(0);
   m_list->autoRowHeight(true);
}

CFontComboBox::CFontComboBox(const char * label,int layoutSize,CLayoutAlign layoutAlignment)
: CComboBox(label,layoutSize,layoutAlignment) {
   loadFonts();
}

#ifdef __COMPATIBILITY_MODE__ 
CFontComboBox::CFontComboBox(int x,int y,int w,int h,const char *l)
: CComboBox(x,y,w,h,l) {
   loadFonts();
}
#endif
